$wnd.rstudio.runAsyncCallback15("function iIi(){}\nfunction gIi(a){this.a=a}\nfunction lIi(a){this.a=a}\nfunction nIi(a){this.a=a}\nfunction nJi(a){this.a=a}\nfunction DHi(a){this.a=a}\nfunction kYf(a){this.a=a}\nfunction iHi(a){uHi(a,new lIi(a))}\nfunction nHi(a){IWf(a.b,new nIi(a))}\nfunction mHi(a){Upk(a.n,new gIi(a),new iIi,iQn)}\nfunction pHi(a){Upk(a.n,new bIi(a,ltn,false),new dIi,xWn)}\nfunction rHi(a,b){Czf(a.d,new b$i(b,true),false)}\nfunction TWf(a,b){(sZd(b),b)&&tHi(a.a,kWo,'')}\nfunction FHi(a,b){this.a=a;this.b=b;rPf.call(this)}\nfunction kIi(a,b){rHi(a.a,'devtools::load_all(\"'+b+'\")')}\nfunction ZJh(a,b){HOh(a,rTn,'devtools_load_all_path',new NH,b)}\nfunction uHi(a,b){a.c!=null?kIi(b,a.c):ZJh(a.j,new FHi(a,b))}\nfunction oHi(a){a.J.qH();en((Zm(),Ym),new DHi(a))}\nfunction BHi(){qOf.call(this,'Terminating Build...')}\nfunction IWf(a,b){uWf(a,jWo,jWo,LYf(a.i.b.package_dependencies,'roxygen'),hWf(a,'roxygen'),false,new kYf(b))}\nfunction fHi(a,b){var c,d;wQf(a.q.d,null);d=b.outputs;for(c=0;c<d.length;c++)EGi(a.q,d[c]);b.errors.length>0&&DGi(a.q,b.errors_base_dir,b.errors,false,0,true,b.type);b.running?X8d(a.a.Rj,true,false):vQf(a.q.d);aZe(a.q.d.c.c)}\nfunction jJi(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=$Ji(a.a.b.a);Ewi(a.a,a.a.a)}switch(a.c){case 1:fHi(a.a.a,a.b[0]);break;case 2:a.a.a.J.oH();break;case 3:a.a.a.J.pH();break;case 4:tHi(a.a.a,RDo,'');break;case 5:tHi(a.a.a,'build-binary-package','');break;case 6:tHi(a.a.a,'build-source-package','');break;case 7:tHi(a.a.a,'check-package','');break;case 8:tHi(a.a.a,'clean-all','');break;case 9:mHi(a.a.a);break;case 10:tHi(a.a.a,SDo,'');break;case 11:nHi(a.a.a);break;case 12:oHi(a.a.a);break;case 13:pHi(a.a.a);break;case 14:JPh(a.a.a.j,new BHi);break;case 15:tHi(a.a.a,'test-package','');break;case 18:a.a.a.J.rH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nvar jWo='Building package documentation',kWo='roxygenize-package';$0c(2211,1,Vqn,kYf);_.Zt=function lYf(a){TWf(this.a,a)};var Gkb=DKd(2211);$0c(6763,379,{},BHi);_.Wm=function CHi(a){(sZd(a),a)||q0c().yC(3,'Error Terminating Build','Unable to terminate build. Please try again.').zC()};var tUb=DKd(6763);$0c(6764,1,$qn,DHi);_.gn=function EHi(){aZe(this.a.q.d.c.c)};var uUb=DKd(6764);$0c(6765,54,{},FHi);_.ev=function GHi(a){this.a.c=a;kIi(this.b,this.a.c)};var vUb=DKd(6765);$0c(6756,1,$qn,gIi);_.gn=function hIi(){iHi(this.a)};var LUb=DKd(6756);$0c(6757,1,$qn,iIi);_.gn=function jIi(){};var MUb=DKd(6757);$0c(6755,1,Vqn,lIi);_.Zt=function mIi(a){kIi(this,a)};var NUb=DKd(6755);$0c(6758,1,$qn,nIi);_.gn=function oIi(){tHi(this.a,kWo,'')};var OUb=DKd(6758);$0c(251,1,iSn);_.en=function mJi(){jJi((new nJi(this)).a)};$0c(6290,1,$qn,nJi);_.gn=function oJi(){jJi(this.a)};var iVb=DKd(6290);Ohn(fm)(15);\n//# sourceURL=rstudio-15.js\n")
