$wnd.rstudio.runAsyncCallback7("function UZj(a){this.a=a}\nfunction cZj(a,b){this.a=a;this.b=b}\nfunction $Yj(a,b){b==null?v9d(a,rLo):v9d(a,b)}\nfunction nZj(a,b){yi(a.d,new ake(false));eZj(a.d,b,0)}\nfunction VMh(a,b){HOh(a,rTn,'markers_tab_closed',new NH,b)}\nfunction _Yj(a,b){var c,d,e,f,g,h,i;d=a.q;Sud(d.o);for(g=b,h=0,i=g.length;h<i;++h){f=g[h];c=new cZj(a,f);e=new C2c(A2c(new B2c,f).a.a);Zdf(d,new Zvd(e,c))}}\nfunction eZj(a,b,c){var d;Rng(a.b);$Yj(a.c,null);_Yj(a.c,DJ(yJ(qY,1),zin,2,6,[]));if(b.markers){d=b.markers;Vng(a.b,null,d.base_path,d.markers,c,false);_Yj(a.c,wre(b.names));$Yj(a.c,d.name)}}\nfunction mZj(a,b){var c,d,e,f,g;g=b.a.markers_state;if(g.markers){yi(a.d,new ake(true));eZj(a.d,b.a.markers_state,b.a.auto_select);e=g.markers;if(e){d=e.markers;if(d.length>0){f=null;c=b.a.auto_select;c==1?(f=d[0]):c==2&&(f=Dng(d));!!f&&I3f(a.b,($le(),qme(f.path,false,-1,0)),w1d(f.line,f.column),false)}}}else{yi(a.d,new Vje)}}\nfunction QZj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=b$j(a.a.b.a);Ewi(a.a,a.a.a)}switch(a.c){case 1:lZj(a.a.a);break;case 2:a.a.a.J.oH();break;case 3:a.a.a.J.pH();break;case 4:VMh(a.a.a.c,new ftf);break;case 5:mZj(a.a.a,a.b[0]);break;case 6:a.a.a.J.qH();break;case 7:a.a.a.J.rH();break;case 8:nZj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\n$0c(7462,1,okn,cZj);_.gn=function dZj(){tE(this.a,this.b)};var jdc=DKd(7462);$0c(427,1,iSn);_.en=function TZj(){QZj((new UZj(this)).a)};$0c(6126,1,$qn,UZj);_.gn=function VZj(){QZj(this.a)};var wdc=DKd(6126);Ohn(fm)(7);\n//# sourceURL=rstudio-7.js\n")
