$wnd.rstudio.runAsyncCallback3("function Qxi(a){this.a=a}\nfunction Sxi(a){this.a=a}\nfunction _xi(a){this.a=a}\nfunction fve(a,b){var c;for(c=0;c<a.q.a.length;c++){if(Ijd(a.q,c).bP==b){Uxe(a.t,CLd(c));break}}}\nfunction Pxi(a,b){this.c=a;this.b=dhi(a.c,B4n,C4n,D4n,Esn).dH();this.a=dhi(a.c,E4n,F4n,G4n,H4n).dH();xi(b,new Qxi(this),$D?$D:($D=new tB))}\nfunction Nxi(a){var b;b=Oxi(a,'weaving Rnw files',a.b,dhi(a.c.c,B4n,C4n,D4n,Esn));b||Oxi(a,'LaTeX typesetting',a.a,dhi(a.c.c,E4n,F4n,G4n,H4n))}\nfunction Lxi(a,b,c){var d;d=usi(a.b.a);kve(d,Eji(oDg((Sqf(),Rqf).a)));!!b&&fve(d,b);qve(d,c);fne(d,true);new Pxi(a,d);(Dwf()||!!$wnd.remoteDesktop)&&Hwf()}\nfunction Xxi(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=GEi(a.a.b.a));switch(a.c){case 1:Lxi(a.a.a,null,true);break;case 2:Lxi(a.a.a,a.b[0],jKd(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nfunction Oxi(a,b,c,d){if(wK(c)!==wK(d.dH())&&wK(d.qr())!==wK(d.dH())){J2d(2,'Project Option Unchanged','You changed the global option for '+b+Aqn+d.dH()+', however the current project is still configured to use '+d.qr()+'.\\n\\nDo you want to edit the options for the current project as well?',new Sxi(a),true);return true}else{return false}}\n$0c(2798,1,{},Pxi);var IRb=DKd(2798);$0c(2799,1,Von,Qxi);_.so=function Rxi(a){Nxi(this.a)};var GRb=DKd(2799);$0c(2800,1,zrn,Sxi);_.gn=function Txi(){A8d(this.a.c.a.hh)};var HRb=DKd(2800);$0c(621,1,iSn);_.en=function $xi(){Xxi((new _xi(this)).a)};$0c(2852,1,$qn,_xi);_.gn=function ayi(){Xxi(this.a)};var JRb=DKd(2852);Ohn(fm)(3);\n//# sourceURL=rstudio-3.js\n")
