$wnd.rstudio.runAsyncCallback23('function b_j(a){this.a=a}\nfunction u$j(a,b){this.a=a;this.b=b}\nfunction g$j(a,b){a.n?L2d(4,\'Stop R Markdown Rendering\',"The rendering of \'"+a.i+"\' is in progress. Do you want to terminate and close the tab?",false,new u$j(a,b),null,null,MPn,trn,true):b.gn()}\nfunction Z$j(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=d_j(a.a.b.a);Ewi(a.a,a.a.a)}switch(a.c){case 1:vGi(a.a.a,a.b[0]);break;case 2:g$j(a.a.a,a.b[0]);break;case 3:h$j(a.a.a);break;case 4:a.a.a.J.oH();break;case 5:a.a.a.J.pH();break;case 6:i$j(a.a.a,a.b[0]);break;case 7:j$j(a.a.a,a.b[0]);break;case 8:k$j(a.a.a,a.b[0]);break;case 9:l$j(a.a.a,a.b[0]);break;case 10:a.a.a.J.qH();break;case 11:a.a.a.J.rH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\n$0c(6858,1,zrn,u$j);_.gn=function v$j(){m$j(this.a);this.b.gn()};var Fdc=DKd(6858);$0c(314,1,iSn);_.en=function a_j(){Z$j((new b_j(this)).a)};$0c(6344,1,$qn,b_j);_.gn=function c_j(){Z$j(this.a)};var Odc=DKd(6344);Ohn(fm)(23);\n//# sourceURL=rstudio-23.js\n')
