$wnd.rstudio.runAsyncCallback16("function yjk(a){this.a=a}\nfunction Xhk(a,b){this.a=a;this.b=b;Nle.call(this)}\nfunction Ahk(a,b){a.a=b;Nik(a.p,whk(a,null),a.a.file_path)}\nfunction Chk(a,b){b.slide_index==0&&GBi(a.p);a.a=b;Nik(a.p,whk(a,null),a.a.file_path)}\nfunction Ihk(a){hhf('Opening Presentation...',rzd());Czf(a.c,new xBf,false)}\nfunction xhk(a){var b;b=OOf(new POf(0,'Closing Presentation...'));tJh(a.n,new Xhk(a,b))}\nfunction tJh(a,b){HOh(a,rTn,'close_presentation_pane',new NH,b)}\nfunction Hhk(a){var b;a.J.qH();!!a.a&&a.a.active&&(b=Nie(Oh(a.p.d).contentWindow),!(!nMd(Krn,b)&&!nMd('javascript:void(0)',b)))&&Ahk(a,a.a)}\nfunction ujk(a){var b,c;try{if(a.c<0)return;if(!a.a.a){a.a.a=ikk(a.a.b.a);Ewi(a.a,a.a.a)}switch(a.c){case 1:xhk((c=a.a.a,a.b[0],c));break;case 2:Chk(a.a.a,a.b[0]);break;case 3:a.a.a.J.oH();break;case 4:a.a.a.J.pH();break;case 5:Hhk(a.a.a);break;case 6:Ihk((b=a.a.a,a.b[0],b));break;case 7:a.a.a.J.rH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\n$0c(6779,32,{},Xhk);_.ev=function Zhk(a){var b;Czf((b=this,a,b).a.c,new xBf,false)};_.dv=function Yhk(a){fOf(this.b,a.a?a.a.c:a.d)};var jjc=DKd(6779);$0c(455,1,iSn);_.en=function xjk(){ujk((new yjk(this)).a)};$0c(6306,1,$qn,yjk);_.gn=function zjk(){ujk(this.a)};var Ijc=DKd(6306);Ohn(fm)(16);\n//# sourceURL=rstudio-16.js\n")
