$wnd.rstudio.runAsyncCallback27("function aZd(){}\nfunction EHj(){}\nfunction fIj(a){this.a=a}\nfunction xHj(a,b){rKj(a.c,b)}\nfunction DYd(a){var b;wYd(a);b=0;while(a.a.Pt(new aZd)){b=z0c(b,1)}return b}\nfunction _Kj(a){var b,c,d;d=new Ujd;for(c=new zre((new xre(Mce(a.i))).a);c.b.length>c.a;){b=c.b[c.a++];Ejd(d,a.i[b])}return d}\nfunction qHj(a,b){var c,d;c=_Kj(NLj(a.d.a));if(c.a.length==0){GOj(a.b,false);b.gn()}d=DYd(EYd(new JYd(null,new SVd(c)),new EHj));if(A0c(d,0)>0){q0c().yC(1,'Local Jobs Still Running','The Jobs tab cannot be closed while there '+(A0c(d,1)>0?'are unfinished local jobs.':'is an unfinished local job.')+'\\n\\nWait until all local jobs have completed.').zC();return}GOj(a.b,false);b.gn()}\nfunction bIj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=ULj(a.a.b.a);Ewi(a.a,a.a.a)}switch(a.c){case 1:qHj(a.a.a,a.b[0]);break;case 2:rHj(a.a.a);break;case 3:a.a.a.J.oH();break;case 4:a.a.a.J.pH();break;case 5:sHj(a.a.a,a.b[0]);break;case 6:tHj(a.a.a,a.b[0]);break;case 7:uHj(a.a.a,a.b[0]);break;case 8:vHj(a.a.a,a.b[0]);break;case 9:wHj(a.a.a,a.b[0]);break;case 10:a.a.a.J.qH();break;case 11:a.a.a.J.rH();break;case 12:xHj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\n$0c(2119,1,{},aZd);_.Tt=function bZd(a){AYd()};var j$=DKd(2119);$0c(6871,1,{},EHj);_.Ut=function FHj(a){return a.type==1&&a.state==2};var Z8b=DKd(6871);$0c(317,1,iSn);_.en=function eIj(){bIj((new fIj(this)).a)};$0c(6365,1,$qn,fIj);_.gn=function gIj(){bIj(this.a)};var e9b=DKd(6365);Ohn(fm)(27);\n//# sourceURL=rstudio-27.js\n")
