$wnd.rstudio.runAsyncCallback17("function Llk(a){this.a=a}\nfunction Fuk(a){this.a=a}\nfunction Huk(a,b){this.a=a;this.b=b}\nfunction Dul(a,b){this.a=a;this.b=b}\nfunction Zul(a,b){this.a=a;this.b=b}\nfunction Itm(a,b){Htm();this.b=a;this.a=b}\nfunction wfm(a,b){hLg(a.u,b)}\nfunction Mgl(a,b){wfm(a.ub,b)}\nfunction tkk(a){LNf(a.n,a.c,null)}\nfunction ukk(a){LNf(a.n,a.g,null)}\nfunction Hkk(a){Ykk(a.o,a.g,Pzo,null)}\nfunction Mkk(a){Ykk(a.o,a.g,'next',null)}\nfunction Okk(a){Ykk(a.o,a.g,'prev',null)}\nfunction Pkk(a){Ykk(a.o,a.g,'refresh',null)}\nfunction vkk(a){LNf(a.n,a.g+'?print-pdf',null)}\nfunction Qdg(a){return {items:a}}\nfunction _pk(a,b){var c;c=a;Tgl(c,b.a)}\nfunction $pk(a,b){en((Zm(),Ym),new Huk(b,a))}\nfunction Fgl(a,b){en((Zm(),Ym),new Zul(a,b))}\nfunction Tgl(a,b){yxm(a.w,RWn,false)?bfl(a,new Dul(a,b)):lzl(a._,b)}\nfunction nkk(a,b){nMd(b.substr(0,4),pmn)||(b=rKh(a.p,b));return b}\nfunction hLg(a,b){a.d.navigateToPresentationEditorLocation(b)}\nfunction vxf(a){$wnd.desktop.setPresentationUrl(a)}\nfunction skk(a){!!a.b&&Czf(a.k,new Itm(($le(),qme(a.b.source_file,false,-1,0)),Kdg(a.d,a.a,a.e)),false)}\nfunction Ldg(a,b){var c,d,e,f;b==-1&&(b=a.auto_slide_level);f=Jdg(a,b,true);for(c=0;c<f.length;c++){e=f[c];for(d=0;d<e.items.length;d++){if(nMd(e.items[d].type,gNn))return c}}return 0}\nfunction Kdg(a,b,c){var d,e,f,g,h;c==-1&&(c=b.auto_slide_level);h=Jdg(b,c,false);if(a<h.length){g=h[a];zl(g.items,Ndg(g.items[0].row))}e=[];for(d=0;d<h.length;d++){g=h[d];for(f=0;f<g.items.length;f++){xl(e,g.items[f])}}return Mdg(e,b.auto_slide_level)}\nfunction lzl(a,b){var c,d,e,f,g,h,i;e=kzl(a).items;d=[];for(g=0;g<e.length;g++){h=e[g];nMd(h.type,gNn)||(d[d.length]=h,undefined)}c=-1;i=b.items;for(f=0;f<i.length;f++){if(nMd(i[f].type,gNn)){c=f;break}}if(c>=0){h=d[c];!!h&&oZk(a.a,Ezm(h.row,0),true)}}\nfunction Jdg(a,b,c){var d,e,f,g,h,i;i=[];g=a.items;for(d=0;d<g.length;d++){f=g[d];e=i.length==0||nMd(f.type,Ojn)||nMd(f.type,'hr')||nMd(f.type,ljn)&&f.level<=b;if(e){h=Qdg([]);xl(h.items,f);i[i.length]=h}else (c||!nMd(f.type,gNn))&&xl(i[i.length-1].items,f)}return i}\nfunction wkk(a,b){var c,d;c=b.a;d=nkk(a,c.url);a.o=Ldg(b.a.editor_state,b.a.slide_level);a.o==0&&a.d!=0&&(a.o=a.d);GBi(a.j);if(!nMd(d,a.g)||!a.j.o){a.g=d;a.c=d;a.b=c.quarto_navigation;a.a=c.editor_state;a.e=c.slide_level;(Dwf()||!!$wnd.remoteDesktop)&&vxf(a.g);Lkk(a.j,a.g,a.b)}else{Pkk(a.j)}}\nfunction Lkk(a,b,c){var d;(Dwf()||!!$wnd.remoteDesktop)&&(u6d(b)?(Oh(a.d).removeAttribute(bNn),undefined):(Oh(a.d).setAttribute(bNn,qVo),undefined));a.b=b;a.o=null;a.g=null;d=Qh(a.d);d>0&&yi(a,new Pje(xK(d*0.6666666666666666)+((a.K?Ph(a.K):0)+(a.O?Ph(a.O):0))));Hrd(a.d,a.b);c.is_website?fGh(a.i):eGh(a.i,c.source_file,c.output_file);Cff(a.p)}\nfunction Hlk(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=kmk(a.a.b.a);Ewi(a.a,a.a.a)}switch(a.c){case 1:a.a.a.J.oH();break;case 2:a.a.a.J.pH();break;case 3:skk(a.a.a);break;case 4:Hkk(a.a.a.j);break;case 5:Mkk(a.a.a.j);break;case 6:tkk(a.a.a);break;case 7:ukk(a.a.a);break;case 8:Okk(a.a.a.j);break;case 9:vkk(a.a.a);break;case 10:wkk(a.a.a,a.b[0]);break;case 11:Pkk(a.a.a.j);break;case 12:a.a.a.J.qH();break;case 13:a.a.a.J.rH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\n$0c(297,1,iSn);_.en=function Klk(){Hlk((new Llk(this)).a)};$0c(6309,1,$qn,Llk);_.gn=function Mlk(){Hlk(this.a)};var $ic=DKd(6309);$0c(3053,1,Vqn,Fuk);_.Zt=function Guk(a){$pk(this.a,a)};var ymc=DKd(3053);$0c(3052,1,okn,Huk);_.gn=function Iuk(){_pk(this.a,this.b)};var zmc=DKd(3052);$0c(4273,1,$qn,Dul);_.gn=function Eul(){Fgl(this.a,this.b)};var KAc=DKd(4273);$0c(4272,1,okn,Zul);_.gn=function $ul(){Mgl(this.a,this.b)};var VAc=DKd(4272);$0c(3097,Xln,{},Itm);_.Vn=function Jtm(a){var b,c;b=(c=O3f(a.k,this.b),!!c&&qK(c,79)?c:(H3f(),C3f));yyk(a.b,this.b,b,new Fuk(this))};_.Xn=function Ltm(){return Gtm};_.Wn=function Ktm(){return Gtm};var DPc=DKd(3097);Ohn(fm)(17);\n//# sourceURL=rstudio-17.js\n")
