$wnd.rstudio.runAsyncCallback9("function IEj(a){this.a=a}\nfunction ADj(a){a.J.qH();U0e(a.j.o)}\nfunction yDj(a){GBi(a.j);rNf(a.a,'Load History','loadhistory')}\nfunction zDj(a){GBi(a.j);wNf(a.a,'Save History As','.Rhistory',false,'savehistory')}\nfunction EEj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=lFj(a.a.b.a);Ewi(a.a,a.a.a)}switch(a.c){case 1:a.a.a.J.oH();break;case 2:a.a.a.J.pH();break;case 3:yDj(a.a.a);break;case 4:zDj(a.a.a);break;case 5:ADj(a.a.a);break;case 6:a.a.a.J.rH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\n$0c(507,1,iSn);_.en=function HEj(){EEj((new IEj(this)).a)};$0c(6225,1,$qn,IEj);_.gn=function JEj(){EEj(this.a)};var l8b=DKd(6225);Ohn(fm)(9);\n//# sourceURL=rstudio-9.js\n")
